@@ -66,8 +66,7 @@ fn real_main() -> Result<()> {
         .subcommand(
             clap::Command::new("sync")
                 .about("Sync Bluetooth device information from nvram")
-                .arg(clap::arg!(-c --config [CONFIG] "Bluez config path."))
-                .arg(clap::Arg::new("variable").multiple_values(true)),
+                .arg(clap::arg!(-c --config [CONFIG] "Bluez config path.")),
         )
         .subcommand(
             clap::Command::new("dump").about("Dump binary Bluetooth device info from nvram"),
@@ -86,9 +85,11 @@ fn real_main() -> Result<()> {
     file.read_to_end(&mut data).unwrap();
     let mut nv = nvram_parse(&data)?;
     let active = nv.active_part_mut();
-    let bt_devs = active
-        .get_variable(bt_var.as_bytes(), VarType::System)
-        .ok_or(Error::VariableNotFound)?;
+    let bt_devs = if let Some(var) = active.get_variable(bt_var.as_bytes(), VarType::System) {
+        var
+    } else {
+        return Ok(());
+    };
 
     match matches.subcommand() {
         Some(("list", _args)) => {
